@@ -1,5 +1,4 @@
 """Cosmographic calculations, and other purely cosmological quantities, such as growth factor."""
 from . import cosmo
-from .cosmo import Cosmology
+from .cosmo import Cosmology, astropy_to_colossus
 from .growth_factor import GrowthFactor
-from .cosmo import astropy_to_colossus
